//$Id: size-entry.h,v 1.2 2001/08/18 14:23:02 cactus Exp $ -*- c++ -*-

/* Guikachu Copyright (C) 2001 RDI Gerg <cactus@cactus.rulez.org>
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2
 * as published by the Free Software Foundation.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA
 */

#ifndef GUIKACHU_WIDGETS_SIZE_ENTRY_H
#define GUIKACHU_WIDGETS_SIZE_ENTRY_H

#include "num-entry.h"

namespace Guikachu
{
    namespace GUI
    {
	class SizeEntry: public NumEntry
	{
	public:
	    SizeEntry (Property<int> &property);
	};
    }
}

#endif /* !GUIKACHU_WIDGETS_SIZE_ENTRY_H */
